/**
  * This file is part of Organiser Feed.
  *
  * Organiser Feed is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Organiser Feed is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with Organiser Feed.  If not, see <http://www.gnu.org/licenses/>.
  *
  */

import QtQuick 1.1

import com.nokia.meego 1.0
import "UIConstants.js" as UIConstants
import organiserfeed 1.0

Page {
    property string uid
    property string calendarName

    id: root

    anchors.fill: parent
    tools: ToolBarLayout {
        id: subPageToolbar
        ToolIcon {
            iconId: "toolbar-back"
            onClicked: pageStack.pop()
        }
    }
    orientationLock: PageOrientation.LockPortrait

    CalendarSettings {
        id: calendar
        uid: root.uid
    }

    SelectionDialog {
        id: lookAheadDialog
        titleText: qsTrId("qtn_look_ahead_time")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            if (!calendar.isDefault())
                model.append({ name: qsTrId("qtn_default"), value: 0 })
            model.append({ name: qsTrId("qtn_time_hour", 3), value: 3 * 60 * 60})
            model.append({ name: qsTrId("qtn_time_hour", 12), value: 12 * 60 * 60})
            model.append({ name: qsTrId("qtn_time_day", 1), value: 24 * 60 * 60 })
            model.append({ name: qsTrId("qtn_time_day", 3), value: 3 * 24 * 60 * 60})
            model.append({ name: qsTrId("qtn_time_week", 1), value: 7 * 24 * 60 * 60 })
            model.append({ name: qsTrId("qtn_time_week", 2), value: 2 * 7 * 24 * 60 * 60 })
            model.append({ name: qsTrId("qtn_time_week", 3), value: 3 * 7 * 24 * 60 * 60 })
        }
    }

    SelectionDialog {
        id: maximumEntriesDialog
        titleText: qsTrId("qtn_maximum_entries_shown")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            if (!calendar.isDefault())
                model.append({ name: qsTrId("qtn_default"), value: 0 })
            model.append({ name: "1", value: 1 })
            model.append({ name: "2", value: 2 })
            model.append({ name: "3", value: 3 })
            model.append({ name: "5", value: 5 })
            model.append({ name: "10", value: 10 })
            model.append({ name: qsTrId("qtn_unlimited"), value: 0xffff })
        }
    }

    SelectionDialog {
        id: includeTodosDialog
        titleText: qsTrId("qtn_include_todos_dialog_title")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            model.append({ name: qsTrId("qtn_default"), value: CalendarSettings.Default })
            model.append({ name: qsTrId("qtn_yes"), value: CalendarSettings.True })
            model.append({ name: qsTrId("qtn_no"), value: CalendarSettings.False })
        }
    }

    SelectionDialog {
        id: includeOverdueTodosDialog
        titleText: qsTrId("qtn_include_overdue_todos_dialog_title")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            model.append({ name: qsTrId("qtn_default"), value: CalendarSettings.Default })
            model.append({ name: qsTrId("qtn_yes"), value: CalendarSettings.True })
            model.append({ name: qsTrId("qtn_no"), value: CalendarSettings.False })
        }
    }

    SelectionDialog {
        id: includeDatelessTodosDialog
        titleText: qsTrId("qtn_include_dateless_todos_dialog_title")
        selectedIndex: 0
        model: ListModel {}

        Component.onCompleted: {
            // Fill model this way in order to be able to use qsTr
            model.append({ name: qsTrId("qtn_default"), value: CalendarSettings.Default })
            model.append({ name: qsTrId("qtn_yes"), value: CalendarSettings.True })
            model.append({ name: qsTrId("qtn_no"), value: CalendarSettings.False })
        }
    }


    function _booleanValueToLabel(value) {
        switch (value) {
        case CalendarSettings.Default:
            return qsTrId("qtn_default");
        case CalendarSettings.True:
            return qsTrId("qtn_yes");
        case CalendarSettings.False:
            return qsTrId("qtn_no");
        }
    }

    function _openDialog(dialog, selectedValue) {
        dialog.open()

         // Set the selected index after opening the dialog - otherwise
         // the model items are not drawn until the screen is touched
         for (var i = 0; i < dialog.model.count; i++) {
             if (dialog.model.get(i).value == selectedValue) {
                 dialog.selectedIndex = i;
                 break;
             }
         }
    }

    Flickable {
        anchors.fill: parent
        flickableDirection: Flickable.VerticalFlick
        contentWidth: width
        contentHeight: content.height

        Column {
            id: content
            width: parent.parent.width

            HeaderItem {
                text: root.calendarName
            }

            RulerItem {}

            SwitchItem {
                id: includeInFeed
                label: qsTrId("qtn_include_in_feed")
                checked: calendar.showInFeed
                onCheckedChanged: { calendar.showInFeed = checked; }
                visible: root.uid != ""
            }

            ComboBoxItem {
                id: lookAhead
                label: qsTrId("qtn_look_ahead")
                value: prettyLookAhead(calendar.lookAhead)
                enabled: includeInFeed.checked

                onShow: _openDialog(lookAheadDialog, calendar.lookAhead)

                Connections {
                    target: lookAheadDialog
                    onSelectedIndexChanged: {
                        calendar.lookAhead = lookAheadDialog.model.get(lookAheadDialog.selectedIndex).value
                    }
                }

                function prettyLookAhead(value) {
                    if (value == 0)
                        return qsTrId("qtn_default");
                    var table = new Array();
                    table.push([ 7 * 24 * 60 * 60, "qtn_time_week"]);
                    table.push([ 24 * 60 * 60, "qtn_time_day" ]);
                    table.push([ 60 * 60, "qtn_time_hour" ]);

                    for (var i = 0; i < table.length; i++) {
                        var res = Math.floor(value / table[i][0])
                        switch (res) {
                        case 0:
                            continue;
                        default:
                            return qsTrId(table[i][1], res);
                        }
                    }
                }
            }

            ComboBoxItem {
                id: maximumEntries
                label: qsTrId("qtn_maximum_entries")
                enabled: includeInFeed.checked
                value: calendar.numberOfEntriesShown == 0xffff ? qsTrId("qtn_unlimited") : (calendar.numberOfEntriesShown == 0 ? qsTrId("qtn_default") : calendar.numberOfEntriesShown)

                onShow: _openDialog(maximumEntriesDialog, calendar.numberOfEntriesShown)

                Connections {
                    target: maximumEntriesDialog
                    onSelectedIndexChanged: {
                        calendar.numberOfEntriesShown = maximumEntriesDialog.model.get(maximumEntriesDialog.selectedIndex).value
                    }
                }
            }

            SwitchItem {
                id: includeTodos
                label: qsTrId("qtn_include_todos")
                checked: calendar.includeTodos === CalendarSettings.True
                onCheckedChanged: { calendar.includeTodos = checked ? CalendarSettings.True : CalendarSettings.False; }
                visible: root.uid == ""
            }

            SwitchItem {
                id: includeOverdueTodos
                label: qsTrId("qtn_include_overdue_todos")
                checked: calendar.includeOverdueTodos === CalendarSettings.True
                onCheckedChanged: { calendar.includeOverdueTodos = checked ? CalendarSettings.True : CalendarSettings.False; }
                enabled: calendar.includeTodos == CalendarSettings.True
                visible: root.uid == ""
            }

            SwitchItem {
                id: includeDatelessTodos
                label: qsTrId("qtn_include_dateless_todos")
                checked: calendar.includeDatelessTodos === CalendarSettings.True
                onCheckedChanged: { calendar.includeDatelessTodos = checked ? CalendarSettings.True : CalendarSettings.False; }
                enabled: calendar.includeTodos == CalendarSettings.True
                visible: root.uid == ""
            }

            ComboBoxItem {
                id: includeTodosSpecific
                label: qsTrId("qtn_include_todos")
                enabled: includeInFeed.checked
                value: _booleanValueToLabel(calendar.includeTodos)
                visible: root.uid != ""

                onShow: _openDialog(includeTodosDialog, calendar.includeTodos)
                Connections {
                    target: includeTodosDialog
                    onSelectedIndexChanged: {
                        calendar.includeTodos = includeTodosDialog.model.get(includeTodosDialog.selectedIndex).value
                    }
                }

            }

            ComboBoxItem {
                id: includeOverdueTodosSpecific
                label: qsTrId("qtn_include_overdue_todos")
                enabled: includeInFeed.checked && calendar.includeTodos != CalendarSettings.False
                value: _booleanValueToLabel(calendar.includeOverdueTodos)
                visible: root.uid != ""

                onShow: _openDialog(includeOverdueTodosDialog, calendar.includeOverdueTodos)
                Connections {
                    target: includeOverdueTodosDialog
                    onSelectedIndexChanged: {
                        calendar.includeOverdueTodos = includeOverdueTodosDialog.model.get(includeOverdueTodosDialog.selectedIndex).value
                    }
                }
            }

            ComboBoxItem {
                id: includeDatelessTodosSpecific
                label: qsTrId("qtn_include_dateless_todos")
                enabled: includeInFeed.checked && calendar.includeTodos != CalendarSettings.False
                value: _booleanValueToLabel(calendar.includeDatelessTodos)
                visible: root.uid != ""

                onShow: _openDialog(includeDatelessTodosDialog, calendar.includeDatelessTodos)
                Connections {
                    target: includeDatelessTodosDialog
                    onSelectedIndexChanged: {
                        calendar.includeDatelessTodos = includeDatelessTodosDialog.model.get(includeDatelessTodosDialog.selectedIndex).value
                    }
                }
            }
        }
    }


}
